@@ -1,7 +1,7 @@
 package WWW::Google::Contacts::Server;
 
 BEGIN {
-    $WWW::Google::Contacts::Server::VERSION = '0.21';
+    $WWW::Google::Contacts::Server::VERSION = '0.22';
 }
 
 use Moose;
@@ -43,6 +43,9 @@ sub _build_authsub {
     my $auth = Net::Google::AuthSub->new( service => 'cp' );
     my $res = $auth->login( $self->username, $self->password );
     unless ( $res and $res->is_success ) {
+        if ($res) {
+            warn $res->{_response}->content;
+        }
         croak "Authentication failed";
     }
     return $auth;
@@ -72,8 +75,8 @@ sub post {
     $headers{'GData-Version'} = $self->gdata_version;
     my $res = $self->ua->post( $id, %headers, Content => $content );
     unless ( $res->is_success ) {
-
-        #use Data::Dumper; print Dumper $res;
+        use Data::Dumper;
+        print Dumper $res;
         croak "POST failed: " . $res->status_line;
     }
     return $res;
